@@ -31,7 +31,7 @@ int main(int argc, char * argv[])
     QApplication app{argc, argv};
     app.setOrganizationName(QStringLiteral("nm-tray"));
     app.setApplicationName(QStringLiteral("nm-tray"));
-    app.setWindowIcon(icons::getIcon(icons::PREFERENCES_NETWORK));
+    app.setWindowIcon(icons::getIcon(icons::PREFERENCES_NETWORK, true));
     app.setQuitOnLastWindowClosed(false);
 
     Tray tray;
