@@ -45,6 +45,7 @@ COPYRIGHT_HEADER*/
 #include <NetworkManagerQt/ConnectionSettings>
 #include <QDBusPendingCallWatcher>
 #include <QInputDialog>
+#include <QMetaEnum>
 
 namespace
 {
@@ -818,7 +819,7 @@ QVariant NmModel::dataRole<NmModel::ActiveConnectionStateRole>(const QModelIndex
         case ITEM_DEVICE_LEAF:
         case ITEM_WIFINET:
         case ITEM_WIFINET_LEAF:
-            return -1;
+            return QVariant{};
         case ITEM_ACTIVE_LEAF:
             return d->mActiveConns[index.row()]->state();
     }
@@ -909,7 +910,7 @@ QVariant NmModel::dataRole<NmModel::IconSecurityRole>(const QModelIndex & index)
 {
     const auto type = dataRole<IconSecurityTypeRole>(index).toInt();
     if (0 <= type)
-        return icons::getIcon(static_cast<icons::Icon>(type));
+        return icons::getIcon(static_cast<icons::Icon>(type), true);
     else
         return QVariant{};
 }
@@ -1156,8 +1157,17 @@ QVariant NmModel::dataRole<NmModel::ActiveConnectionInfoRole>(const QModelIndex
             << QStringLiteral("<tr><td><strong>") << NmModel::tr("Driver", "Active connection information") << QStringLiteral("</strong>: </td><td>")
                 << dev->driver() << QStringLiteral("</td></tr>")
             << QStringLiteral("<tr><td><strong>") << NmModel::tr("Speed", "Active connection information") << QStringLiteral("</strong>: </td><td>");
-        if (0 <= bit_rate)
-            str << bit_rate << NmModel::tr(" Kb/s");
+        if (0 <= bit_rate) 
+        {
+            if (bit_rate <= 1000)
+                str << bit_rate << "&nbsp;" << NmModel::tr("Kb/s");
+            else if (bit_rate <= 1000000)
+                str << QLocale::system().toString(static_cast<double>(bit_rate) / 1000, 'g', 5) << "&nbsp;" << NmModel::tr("Mb/s");
+            else if (bit_rate <= 1000000000)
+                str << QLocale::system().toString(static_cast<double>(bit_rate)/1000000, 'g', 5) << "&nbsp;" << NmModel::tr("Gb/s");
+            else
+                str << QLocale::system().toString(static_cast<double>(bit_rate)/1000000000, 'g', 5) << "&nbsp;" << NmModel::tr("Tb/s");
+        }
         else
             str << NmModel::tr("unknown", "Speed");
         str << QStringLiteral("</td></tr>");
@@ -1221,16 +1231,16 @@ QVariant NmModel::dataRole<NmModel::IconTypeRole>(const QModelIndex & index) con
         case ITEM_CONNECTION_LEAF:
         case ITEM_DEVICE_LEAF:
             {
-                auto type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(dataRole<ConnectionTypeRole>(index).toInt());
-                auto state = static_cast<NetworkManager::ActiveConnection::State>(dataRole<ActiveConnectionStateRole>(index).toInt());
+                const int type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(dataRole<ConnectionTypeRole>(index).toInt());
+                const QVariant state = dataRole<ActiveConnectionStateRole>(index);
                 //TODO other types?
                 switch (type)
                 {
                     case NetworkManager::ConnectionSettings::Wireless:
                     case NetworkManager::ConnectionSettings::Wimax:
-                        if (0 > state)
+                        if (!state.isValid())
                             return icons::NETWORK_WIFI_DISCONNECTED;
-                        switch (state)
+                        switch (static_cast<NetworkManager::ActiveConnection::State>(state.toInt()))
                         {
                             case NetworkManager::ActiveConnection::Activating:
                                 return icons::NETWORK_WIFI_ACQUIRING;
@@ -1243,6 +1253,7 @@ QVariant NmModel::dataRole<NmModel::IconTypeRole>(const QModelIndex & index) con
                         }
                         break;
                     case NetworkManager::ConnectionSettings::Vpn:
+                    case NetworkManager::ConnectionSettings::WireGuard:
                         return icons::NETWORK_VPN;
                     default:
                         return NetworkManager::ActiveConnection::Activated == state ? icons::NETWORK_WIRED : icons::NETWORK_WIRED_DISCONNECTED;
@@ -1258,7 +1269,7 @@ QVariant NmModel::dataRole<NmModel::IconTypeRole>(const QModelIndex & index) con
 template <>
 QVariant NmModel::dataRole<NmModel::IconRole>(const QModelIndex & index) const
 {
-    return icons::getIcon(static_cast<icons::Icon>(dataRole<IconTypeRole>(index).toInt()));
+    return icons::getIcon(static_cast<icons::Icon>(dataRole<IconTypeRole>(index).toInt()), true);
 }
 
 QVariant NmModel::data(const QModelIndex &index, int role) const
@@ -1454,7 +1465,7 @@ void NmModel::activateConnection(QModelIndex const & index)
                 auto const & conn = d->mConnections[index.row()];
                 conn_uni = conn->path();
                 conn_name = conn->name();
-                if (NetworkManager::ConnectionSettings::Vpn == conn->settings()->connectionType())
+                if (NetworkManager::ConnectionSettings::Vpn == conn->settings()->connectionType() || NetworkManager::ConnectionSettings::WireGuard == conn->settings()->connectionType())
                 {
                     spec_object = dev_uni = QStringLiteral("/");
                     /*
