@@ -12,22 +12,17 @@
 <context>
     <name>NmList</name>
     <message>
-        <location filename="../src/nmlist.ui" line="14"/>
-        <source>Dialog</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/nmlist.ui" line="20"/>
+        <location filename="../src/nmlist.ui" line="17"/>
         <source>All information</source>
         <translation>Al information</translation>
     </message>
     <message>
-        <location filename="../src/nmlist.ui" line="30"/>
+        <location filename="../src/nmlist.ui" line="27"/>
         <source>Active connections</source>
         <translation>Aktive forbindelser</translation>
     </message>
     <message>
-        <location filename="../src/nmlist.ui" line="40"/>
+        <location filename="../src/nmlist.ui" line="37"/>
         <source>Available wireless</source>
         <translation>Tilgængelige trådløse</translation>
     </message>
@@ -35,125 +30,140 @@
 <context>
     <name>NmModel</name>
     <message>
-        <location filename="../src/nmmodel.cpp" line="55"/>
+        <location filename="../src/nmmodel.cpp" line="56"/>
         <source>nm-tray - wireless password</source>
         <translation>nm-tray - adgangskode til trådløs</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="56"/>
+        <location filename="../src/nmmodel.cpp" line="57"/>
         <source>Password is needed for connection to &apos;%1&apos;:</source>
         <translation>Der kræves adgangskode for at oprette forbindelse til &apos;%1&apos;:</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="744"/>
+        <location filename="../src/nmmodel.cpp" line="745"/>
         <source>root</source>
-        <translation></translation>
+        <translation>rod</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="746"/>
+        <location filename="../src/nmmodel.cpp" line="747"/>
         <source>active connection(s)</source>
         <translation>aktive forbindelser</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="748"/>
+        <location filename="../src/nmmodel.cpp" line="749"/>
         <source>connection(s)</source>
         <translation>forbindelse(r)</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="750"/>
+        <location filename="../src/nmmodel.cpp" line="751"/>
         <source>device(s)</source>
         <translation>enhed(er)</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="752"/>
+        <location filename="../src/nmmodel.cpp" line="753"/>
         <source>wifi network(s)</source>
         <translation>wifi-netværk</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1043"/>
+        <location filename="../src/nmmodel.cpp" line="1044"/>
         <source>unknown</source>
         <comment>hardware address</comment>
         <translation>ukendt</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1151"/>
+        <location filename="../src/nmmodel.cpp" line="1152"/>
         <source>General</source>
         <comment>Active connection information</comment>
         <translation>Generelt</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1152"/>
+        <location filename="../src/nmmodel.cpp" line="1153"/>
         <source>Interface</source>
         <comment>Active connection information</comment>
         <translation>Grænseflade</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1154"/>
+        <location filename="../src/nmmodel.cpp" line="1155"/>
         <source>Hardware Address</source>
         <comment>Active connection information</comment>
         <translation>Hardwareadresse</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1156"/>
+        <location filename="../src/nmmodel.cpp" line="1157"/>
         <source>Driver</source>
         <comment>Active connection information</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1158"/>
+        <location filename="../src/nmmodel.cpp" line="1159"/>
         <source>Speed</source>
         <comment>Active connection information</comment>
         <translation>Hastighed</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1160"/>
-        <source> Kb/s</source>
-        <translation></translation>
+        <location filename="../src/nmmodel.cpp" line="1163"/>
+        <source>Kb/s</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1162"/>
+        <location filename="../src/nmmodel.cpp" line="1165"/>
+        <source>Mb/s</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/nmmodel.cpp" line="1167"/>
+        <source>Gb/s</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/nmmodel.cpp" line="1169"/>
+        <source>Tb/s</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/nmmodel.cpp" line="1172"/>
         <source>unknown</source>
         <comment>Speed</comment>
         <translation>ukendt</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1166"/>
+        <location filename="../src/nmmodel.cpp" line="1176"/>
         <source>Security</source>
         <comment>Active connection information</comment>
         <translation>Sikkerhed</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1170"/>
+        <location filename="../src/nmmodel.cpp" line="1180"/>
         <source>IPv4</source>
         <comment>Active connection information</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1171"/>
+        <location filename="../src/nmmodel.cpp" line="1181"/>
         <source>IPv6</source>
         <comment>Active connection information</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1182"/>
+        <location filename="../src/nmmodel.cpp" line="1192"/>
         <source>IP Address</source>
         <comment>Active connection information</comment>
         <translation>IP-adresse</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1184"/>
+        <location filename="../src/nmmodel.cpp" line="1194"/>
         <source>Subnet Mask</source>
         <comment>Active connection information</comment>
-        <translation>Subnet-maske</translation>
+        <translation>Subnetmaske</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1193"/>
+        <location filename="../src/nmmodel.cpp" line="1203"/>
         <source>Default route</source>
         <comment>Active connection information</comment>
         <translation>Standardrute</translation>
     </message>
     <message>
-        <location filename="../src/nmmodel.cpp" line="1199"/>
+        <location filename="../src/nmmodel.cpp" line="1209"/>
         <source>DNS(%1)</source>
         <comment>Active connection information</comment>
         <translation></translation>
@@ -209,7 +219,7 @@
     <message>
         <location filename="../src/tray.cpp" line="256"/>
         <source>Enable notifications</source>
-        <translation>Aktivér notifikationer</translation>
+        <translation>Aktivér underretninger</translation>
     </message>
     <message>
         <location filename="../src/tray.cpp" line="258"/>
@@ -219,17 +229,17 @@
     <message>
         <location filename="../src/tray.cpp" line="259"/>
         <source>Debug information</source>
-        <translation>Fejlretinformation</translation>
+        <translation>Fejlretningsinformation</translation>
     </message>
     <message>
         <location filename="../src/tray.cpp" line="260"/>
         <source>Wifi - request scan</source>
-        <translation type="unfinished"></translation>
+        <translation>Wifi - anmod om skanning</translation>
     </message>
     <message>
         <location filename="../src/tray.cpp" line="261"/>
         <source>Edit connections...</source>
-        <translation>Rediger forbindelser...</translation>
+        <translation>Rediger forbindelser ...</translation>
     </message>
     <message>
         <location filename="../src/tray.cpp" line="264"/>
